/*
-----------------------------------------------------------------------------
This source file is part of OGRE
    (Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright  2000-2002 The OGRE Team
Also see acknowledgements in Readme.html

This program is free software; you can redistribute it and/or modify it under
the terms of the GNU Lesser General Public License as published by the Free Software
Foundation; either version 2 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 59 Temple
Place - Suite 330, Boston, MA 02111-1307, USA, or go to
http://www.gnu.org/copyleft/lesser.txt.
-----------------------------------------------------------------------------
*/

#include <OgreOcclusionCullingTerrainSceneManager.h>
#include <OgreOcclusionCullingOctreeSceneManager.h>
//#include <OgreOcclusionCullingDotSceneManager.h>
#include <OgreHeightmapTerrainPageSource.h>
#include "GtpVisibilityManager.h"
#include "GtpVisibilityStopAndWaitManager.h"
#include "GtpVisibilityEnvironment.h"

#include <OgreRoot.h>

//#include <windows.h>
GtpVisibility::Environment *visEnv;
GtpVisibility::Manager *visManager;

namespace Ogre {

// OcclusionCullingDotSceneManager *occlusionDotPlugin;
OcclusionCullingOctreeSceneManager *cullingOctreePlugin;
OcclusionCullingTerrainSceneManager *cullingTerrainPlugin;

HeightmapTerrainPageSource *heightmapTerrainPageSource;

//-----------------------------------------------------------------------
extern "C" void dllStartPlugin(void)
{
	visManager = new GtpVisibility::Manager(visEnv);
	// Create new scene manager
	//occlusionDotPlugin = new OcclusionCullingDotSceneManager();
	cullingOctreePlugin = new OcclusionCullingOctreeSceneManager(visManager);
	cullingTerrainPlugin = new OcclusionCullingTerrainSceneManager(visManager);
	heightmapTerrainPageSource = new HeightmapTerrainPageSource();

	cullingTerrainPlugin->registerPageSource("Heightmap", heightmapTerrainPageSource);

	// Register
	//Root::getSingleton().setSceneManager( ST_GENERIC, occlusionDotPlugin );
	Root::getSingleton().setSceneManager( ST_GENERIC, cullingOctreePlugin );
	Root::getSingleton().setSceneManager( ST_EXTERIOR_CLOSE, cullingTerrainPlugin );
}
extern "C" void dllStopPlugin(void)
{
	delete heightmapTerrainPageSource;
    //delete occlusionDotPlugin;
	delete cullingOctreePlugin;
	delete cullingTerrainPlugin;
	delete visManager;
}

} //namespace Ogre
